@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2023 -- leonerd@leonerd.org.uk
 
-package Net::Async::HTTP::StallTimer;
+package Net::Async::HTTP::StallTimer 0.50;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( IO::Async::Timer::Countdown );
 
-our $VERSION = '0.45';
-
 sub _init
 {
    my $self = shift;
